<?xml version='1.0' encoding="utf-8"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:csw="http://www.opengis.net/cat/csw"
xmlns:ows="http://www.opengis.net/ows" 
xmlns:xlink="http://www.w3.org/1999/xlink"
xmlns:ogc="http://www.opengis.net/ogc"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
>
<!-- main template -->
<xsl:output method="html" omit-xml-declaration="no" indent="yes" encoding="utf-8" media-type="text/xml; charset=utf-8" />
<xsl:template match="/">
	<html xmlns="http://www.w3.org/1999/xhtml">
	<header>
		<title>
	 		GetCapabilities - 
			<xsl:value-of select="csw:Capabilities/ows:ServiceIdentification/ows:Title" />
		</title>
	</header>
	<body>	
	<h1 style="text-align:right">GetCapabilities</h1>
	<h2 style="color:white;background-color:#666666;padding:5px;">Service Identification</h2>
		<xsl:apply-templates select="/csw:Capabilities/ows:ServiceIdentification" />
	<h2 style="color:white;background-color:#666666;padding:5px;">Service Provider</h2>
		<xsl:apply-templates select="/csw:Capabilities/ows:ServiceProvider" />
	<h2 style="color:white;background-color:#666666;padding:5px;">Operations Metadata</h2>
		<xsl:apply-templates select="/csw:Capabilities/ows:OperationsMetadata" />
	<h2 style="color:white;background-color:#666666;padding:5px;">Filter Capabilities</h2>
		<xsl:apply-templates select="/csw:Capabilities/ogc:Filter_Capabilities" />
	</body>
	</html>

</xsl:template>

<!-- Variables -->
<xsl:variable name="colgroup">
	<colgroup style="color:green;background-color:#eeeeee;padding:5px 25px 5px 25px;font-size:1.1em;width:25%" />
</xsl:variable>

<!-- templates -->
<!-- Section 1 Service Identification -->
<xsl:template match="ows:ServiceIdentification">
	<table width="95%" style="margin:auto">
	<xsl:copy-of select="$colgroup" />
 	<tr>
		<td>Title of service</td>
		<td><xsl:value-of select="ows:Title" /></td>
	</tr>
	<tr>
		<td>Abstract</td>
		<td><xsl:value-of select="ows:Abstract" /></td>
	</tr>
	<tr>
		<td>Keywords</td>
		<td>
			<xsl:for-each select="ows:Keywords/ows:Keyword">
				<xsl:value-of select="current()" />
				<xsl:text> </xsl:text>
			</xsl:for-each>
		</td>
	</tr>
	<tr>
		<td>Service type and Version</td>
		<td>
			<xsl:value-of select="ows:ServiceType" />
			<xsl:text> </xsl:text>
			<xsl:value-of select="ows:ServiceTypeVersion" />
		</td>
	</tr>
	<tr>
		<td>Fees</td>
		<td><xsl:value-of select="ows:Fees" /></td>
	</tr>
	<tr>
		<td>Access constraints</td>
		<td><xsl:value-of select="ows:AccessConstraints" /></td>
	</tr>
 </table>
</xsl:template>

<!-- Section 2 Servis Provider-->
<xsl:template match="ows:ServiceProvider">
	<table width="95%" style="margin:auto">
	<xsl:copy-of select="$colgroup" />
	<tr>
		<td>Provider name</td>
		<td><xsl:value-of select="ows:ProviderName" /></td>
	</tr>
	<tr>
		<td>Provider Site</td>
		<td>
			<xsl:element name="a" >
				<xsl:attribute name="href"><xsl:value-of select="ows:ProviderSite" /></xsl:attribute>
				<xsl:value-of select="ows:ProviderSite" />
			</xsl:element>
		</td>		
	</tr>
	<tr>
		<td>Service Contact</td>
		<td>
			<xsl:value-of select="ows:ServiceContact/ows:IndividualName" /> (<xsl:value-of select="ows:ServiceContact/ows:PositionName" />)<br />
			e-mail:
			<xsl:element name="a">
				<xsl:attribute name="href">mailto:<xsl:value-of select="ows:ServiceContact/ows:ContactInfo/ows:Address/ows:ElectronicMailAddress" />
				</xsl:attribute>
				<xsl:value-of select="ows:ServiceContact/ows:ContactInfo/ows:Address/ows:ElectronicMailAddress" />
			</xsl:element>
			<br />
			phone: <xsl:value-of select="ows:ServiceContact/ows:ContactInfo/ows:Phone/ows:Voice" /><br />
			Facsimile: <xsl:value-of select="ows:ServiceContact/ows:ContactInfo/ows:Phone/ows:Facsimile" /><br />
		</td>		
	</tr>

</table>
</xsl:template>
<!-- Section 3 Operation Metadata -->
<xsl:template match="ows:OperationsMetadata">
	<xsl:for-each select="ows:Operation">
		<h3><xsl:value-of select="@name" /> operation</h3>
		<div style="margin:auto;width:95%;border:1px solid green;margin-bottom:25px;padding:5px;">
		<!-- get -->
		<h4>GET adress</h4>
		<xsl:element name="a">
			<xsl:attribute name="href">
			<xsl:value-of select="ows:DCP/ows:HTTP/ows:Get/@xlink:href" />
			</xsl:attribute>
			<xsl:value-of select="ows:DCP/ows:HTTP/ows:Get/@xlink:href" />
		</xsl:element>
		<br />
		<!-- post -->
		<h4>POST adress</h4>
		<xsl:element name="a">
			<xsl:attribute name="href">
			<xsl:value-of select="ows:DCP/ows:HTTP/ows:Post/@xlink:href" />
			</xsl:attribute>
			<xsl:value-of select="ows:DCP/ows:HTTP/ows:Post/@xlink:href" />
		</xsl:element>
		<h4>Parameters</h4>
		<table width="100%">
		<xsl:copy-of select="$colgroup" />
		<xsl:for-each select="ows:Parameter">
			<tr>
				<td><xsl:value-of select="@name" /></td>
				<td><xsl:value-of select="ows:Value" /></td>
			</tr>
		</xsl:for-each>
		</table>
		</div>
	</xsl:for-each>
</xsl:template>
<!-- Section 4 Filter Capabilities -->
<xsl:template match="ogc:Filter_Capabilities">
	<h3>Spatial Capabilities</h3>
	<div style="margin:auto;width:95%;border:1px solid green;margin-bottom:25px;padding:5px;">
	<h4>Geometry Operands</h4>
	<ul>
		<xsl:for-each select="ogc:Spatial_Capabilities/ogc:GeometryOperands">
		<li><xsl:value-of select="ogc:GeometryOperand" /></li>
		</xsl:for-each>
	</ul>
	<h4>Spatial Operands</h4>
	<ul>
		<xsl:for-each select="ogc:Spatial_Capabilities/ogc:SpatialOperators">
		<li><xsl:value-of select="ogc:SpatialOperator/@name" /></li>
		</xsl:for-each>
	</ul>
	</div>

	<h3>Scalar Capabilities</h3>
	<div style="margin:auto;width:95%;border:1px solid green;margin-bottom:25px;padding:5px;">
	<h4>Logical Operators</h4>
	<xsl:value-of select="ogc:Scalar_Capabilities/ogc:LogicalOperators" />	
	<h4>Comparasion Operators</h4>
	<ul>
		<xsl:for-each select="ogc:Scalar_Capabilities/ogc:ComparisonOperators/ogc:ComparisonOperator">
		<li><xsl:value-of select="current()" /></li>
		</xsl:for-each>
	</ul>
	</div>
</xsl:template>


<xsl:template match="ows:DCP">
	
</xsl:template>
</xsl:stylesheet><!-- Stylus Studio meta-information - (c) 2004-2006. Progress Software Corporation. All rights reserved.
<metaInformation>
<scenarios ><scenario default="yes" name="GetCapabilities_to_XHTML" userelativepaths="yes" externalpreview="no" url="GetCapabilities_response.xml" htmlbaseurl="" outputurl="" processortype="internal" useresolver="yes" profilemode="0" profiledepth="" profilelength="" urlprofilexml="" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext="" validateoutput="no" validator="internal" customvalidator=""/></scenarios><MapperMetaTag><MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/><MapperBlockPosition></MapperBlockPosition><TemplateContext></TemplateContext><MapperFilter side="source"></MapperFilter></MapperMetaTag>
</metaInformation>
-->