<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:csw="http://www.opengis.net/cat/csw"
xmlns:ows="http://www.opengis.net/ows" 
xmlns:xlink="http://www.w3.org/1999/xlink"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xsi:schemaLocation="http://www.opengis.net/cat/csw http://schemas.opengis.net/csw/2.0.1/CSW-discovery.xsd"
>
<!--

	Create plain text KVP encoding values from GetCapabilities XML document
	
	NOTE:

		values in input XML must exactly correspond with XSD document
		http://schemas.opengis.net/csw/2.0.1/CSW-discovery.xsd

		response KVP encoded text correspond with 
		ISO19115/ISO19119 Application Profile for CSW 2.0 [OGC 04-038r2]
	
	USE: translat XML request determine for GeoNetwork into Micka

	Author: Roman Ozana, oza018@vsb.cz, 2006

-->
<xsl:template match="/csw:GetCapabilities">
	
	<!-- Is document CSW GetCapabilities request ? -->
	<xsl:if test="@service = 'http://www.opengis.net/cat/csw' or @service = 'CSW'">
		
		<!-- Request string (mandatory) -->
		<xsl:text>REQUEST=GetCapabilities</xsl:text>
			
		<!-- Service parameter (mandatory) -->
		<xsl:text>&amp;SERVICE=</xsl:text>	

 		<!--
			in doc is permitted CSW string,
			but in XSD is set as default value link
			http://www.opengis.net/cat/csw
		-->
		<xsl:text>CSW</xsl:text>
	
		<!-- Accept Version paranmeter (optional) -->
		<xsl:if test="ows:AcceptVersions/ows:Version != ''">
			<xsl:text>&amp;ACCEPTVERSIONS=</xsl:text>
			<xsl:value-of select="ows:AcceptVersions/ows:Version" />
		</xsl:if>

		<!-- Sections parameter (optional) -->
		<xsl:if test="ows:Sections/ows:Section != ''">
			<xsl:text>&amp;SECTIONS=</xsl:text>		
			<xsl:value-of select="ows:Sections/ows:Section" />
		</xsl:if>

		<!-- Update update sequence parameter (optional) -->
		<xsl:if test="@updateSequence != ''">
			<xsl:text>&amp;UPDATESEQUENCE=</xsl:text>		
			<xsl:value-of select="ows:Sections/ows:Section" />
		</xsl:if>

		<!-- Accept formats (optional) -->
		<xsl:if test="ows:AcceptFormats/ows:OutputFormat != ''">
			<xsl:text>&amp;ACCEPTFORMATS=</xsl:text>		
			<xsl:value-of select="ows:AcceptFormats/ows:OutputFormat" />
		</xsl:if>

	</xsl:if>
</xsl:template>
</xsl:stylesheet><!-- Stylus Studio meta-information - (c) 2004-2006. Progress Software Corporation. All rights reserved.
<metaInformation>
<scenarios ><scenario default="yes" name="GetCapabilities.xml" userelativepaths="yes" externalpreview="no" url="GetCapabilities.xml" htmlbaseurl="" outputurl="" processortype="internal" useresolver="yes" profilemode="0" profiledepth="" profilelength="" urlprofilexml="" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext="" validateoutput="no" validator="internal" customvalidator=""/></scenarios><MapperMetaTag><MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no" ><SourceSchema srcSchemaPath="GetCapabilities.xml" srcSchemaRoot="GetCapabilities" AssociatedInstance="" loaderFunction="document" loaderFunctionUsesURI="no"/></MapperInfo><MapperBlockPosition></MapperBlockPosition><TemplateContext></TemplateContext><MapperFilter side="source"></MapperFilter></MapperMetaTag>
</metaInformation>
-->